@@ -1,5 +1,5 @@
 # emacs: -*- mode: python; py-indent-offset: 4; tab-width: 4; indent-tabs-mode: nil -*-
-# ex: set sts=4 ts=4 sw=4 noet:
+# ex: set sts=4 ts=4 sw=4 et:
 # ## ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ##
 #
 #   See COPYING file distributed along with the datalad package for the
@@ -466,16 +466,8 @@ def test_get_local_file_url():
                 #('/a b/', 'file:///a%20b/'),
                 ('/a b/name', 'file:///a%20b/name'),
             ):
-        try:
-            # Yarik found no better way to trigger.  .decode() isn't enough
-            print("D: %s" % path)
-        except UnicodeEncodeError:
-            if sys.version_info < (3, 7):
-                # observed test failing on ubuntu 18.04 with python 3.6
-                # (reproduced in conda env locally with python 3.6.10 when LANG=C
-                # We will just skip this tricky one
-                continue
-            raise
+        # Yarik found no better way to trigger.  .decode() isn't enough
+        print("D: %s" % path)
         if isabs(path):
             eq_(get_local_file_url(path), url)
         else:
